@@ -3,13 +3,14 @@ Main interface for autoscaling-plans service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.autoscaling_plans import (
+    from mypy_boto3_autoscaling_plans import (
         AutoScalingPlansClient,
         Client,
         DescribeScalingPlanResourcesPaginator,
         DescribeScalingPlansPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,16 +19,16 @@ Usage::
 
     describe_scaling_plan_resources_paginator: DescribeScalingPlanResourcesPaginator = client.get_paginator("describe_scaling_plan_resources")
     describe_scaling_plans_paginator: DescribeScalingPlansPaginator = client.get_paginator("describe_scaling_plans")
+    ```
 """
-from mypy_boto3_autoscaling_plans.client import (
-    AutoScalingPlansClient,
-    AutoScalingPlansClient as Client,
-)
+from mypy_boto3_autoscaling_plans.client import AutoScalingPlansClient
 from mypy_boto3_autoscaling_plans.paginator import (
     DescribeScalingPlanResourcesPaginator,
     DescribeScalingPlansPaginator,
 )
 
+Client = AutoScalingPlansClient
+
 
 __all__ = (
     "AutoScalingPlansClient",
