@@ -3,19 +3,19 @@ Main interface for autoscaling-plans service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.autoscaling_plans import AutoScalingPlansClient
-
-    session = boto3.Session()
+    from mypy_boto3_autoscaling_plans import AutoScalingPlansClient
 
     client: AutoScalingPlansClient = boto3.client("autoscaling-plans")
-    session_client: AutoScalingPlansClient = session.client("autoscaling-plans")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
-from botocore.exceptions import ClientError as Boto3ClientError
+from datetime import datetime
+from typing import Any, Dict, List, Type, overload
+
+from botocore.client import ClientMeta
+
 from mypy_boto3_autoscaling_plans.paginator import (
     DescribeScalingPlanResourcesPaginator,
     DescribeScalingPlansPaginator,
@@ -38,41 +38,50 @@ else:
 __all__ = ("AutoScalingPlansClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    ConcurrentUpdateException: Type[Boto3ClientError]
-    InternalServiceException: Type[Boto3ClientError]
-    InvalidNextTokenException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    ObjectNotFoundException: Type[Boto3ClientError]
-    ValidationException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    ConcurrentUpdateException: Type[BotocoreClientError]
+    InternalServiceException: Type[BotocoreClientError]
+    InvalidNextTokenException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    ObjectNotFoundException: Type[BotocoreClientError]
+    ValidationException: Type[BotocoreClientError]
 
 
 class AutoScalingPlansClient:
     """
-    [AutoScalingPlans.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client)
+    [AutoScalingPlans.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.can_paginate)
         """
 
     def create_scaling_plan(
         self,
         ScalingPlanName: str,
-        ApplicationSource: ApplicationSourceTypeDef,
-        ScalingInstructions: List[ScalingInstructionTypeDef],
+        ApplicationSource: "ApplicationSourceTypeDef",
+        ScalingInstructions: List["ScalingInstructionTypeDef"],
     ) -> CreateScalingPlanResponseTypeDef:
         """
-        [Client.create_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.create_scaling_plan)
+        [Client.create_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.create_scaling_plan)
         """
 
     def delete_scaling_plan(self, ScalingPlanName: str, ScalingPlanVersion: int) -> Dict[str, Any]:
         """
-        [Client.delete_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.delete_scaling_plan)
+        [Client.delete_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.delete_scaling_plan)
         """
 
     def describe_scaling_plan_resources(
@@ -83,19 +92,19 @@ class AutoScalingPlansClient:
         NextToken: str = None,
     ) -> DescribeScalingPlanResourcesResponseTypeDef:
         """
-        [Client.describe_scaling_plan_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.describe_scaling_plan_resources)
+        [Client.describe_scaling_plan_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.describe_scaling_plan_resources)
         """
 
     def describe_scaling_plans(
         self,
         ScalingPlanNames: List[str] = None,
         ScalingPlanVersion: int = None,
-        ApplicationSources: List[ApplicationSourceTypeDef] = None,
+        ApplicationSources: List["ApplicationSourceTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None,
     ) -> DescribeScalingPlansResponseTypeDef:
         """
-        [Client.describe_scaling_plans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.describe_scaling_plans)
+        [Client.describe_scaling_plans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.describe_scaling_plans)
         """
 
     def generate_presigned_url(
@@ -106,7 +115,7 @@ class AutoScalingPlansClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.generate_presigned_url)
         """
 
     def get_scaling_plan_resource_forecast_data(
@@ -135,18 +144,18 @@ class AutoScalingPlansClient:
         EndTime: datetime,
     ) -> GetScalingPlanResourceForecastDataResponseTypeDef:
         """
-        [Client.get_scaling_plan_resource_forecast_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.get_scaling_plan_resource_forecast_data)
+        [Client.get_scaling_plan_resource_forecast_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.get_scaling_plan_resource_forecast_data)
         """
 
     def update_scaling_plan(
         self,
         ScalingPlanName: str,
         ScalingPlanVersion: int,
-        ApplicationSource: ApplicationSourceTypeDef = None,
-        ScalingInstructions: List[ScalingInstructionTypeDef] = None,
+        ApplicationSource: "ApplicationSourceTypeDef" = None,
+        ScalingInstructions: List["ScalingInstructionTypeDef"] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.update_scaling_plan)
+        [Client.update_scaling_plan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Client.update_scaling_plan)
         """
 
     @overload
@@ -154,7 +163,7 @@ class AutoScalingPlansClient:
         self, operation_name: Literal["describe_scaling_plan_resources"]
     ) -> DescribeScalingPlanResourcesPaginator:
         """
-        [Paginator.DescribeScalingPlanResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources)
+        [Paginator.DescribeScalingPlanResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources)
         """
 
     @overload
@@ -162,5 +171,5 @@ class AutoScalingPlansClient:
         self, operation_name: Literal["describe_scaling_plans"]
     ) -> DescribeScalingPlansPaginator:
         """
-        [Paginator.DescribeScalingPlans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans)
+        [Paginator.DescribeScalingPlans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans)
         """
