@@ -3,8 +3,11 @@ Main interface for autoscaling-plans service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.autoscaling_plans import (
+
+    from mypy_boto3_autoscaling_plans import AutoScalingPlansClient
+    from mypy_boto3_autoscaling_plans.paginator import (
         DescribeScalingPlanResourcesPaginator,
         DescribeScalingPlansPaginator,
     )
@@ -13,10 +16,12 @@ Usage::
 
     describe_scaling_plan_resources_paginator: DescribeScalingPlanResourcesPaginator = client.get_paginator("describe_scaling_plan_resources")
     describe_scaling_plans_paginator: DescribeScalingPlansPaginator = client.get_paginator("describe_scaling_plans")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_autoscaling_plans.type_defs import (
     ApplicationSourceTypeDef,
     DescribeScalingPlanResourcesResponseTypeDef,
@@ -24,13 +29,12 @@ from mypy_boto3_autoscaling_plans.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("DescribeScalingPlanResourcesPaginator", "DescribeScalingPlansPaginator")
 
 
 class DescribeScalingPlanResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeScalingPlanResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources)
+    [Paginator.DescribeScalingPlanResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources)
     """
 
     def paginate(
@@ -40,22 +44,22 @@ class DescribeScalingPlanResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeScalingPlanResourcesResponseTypeDef]:
         """
-        [DescribeScalingPlanResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources.paginate)
+        [DescribeScalingPlanResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlanResources.paginate)
         """
 
 
 class DescribeScalingPlansPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeScalingPlans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans)
+    [Paginator.DescribeScalingPlans documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans)
     """
 
     def paginate(
         self,
         ScalingPlanNames: List[str] = None,
         ScalingPlanVersion: int = None,
-        ApplicationSources: List[ApplicationSourceTypeDef] = None,
+        ApplicationSources: List["ApplicationSourceTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeScalingPlansResponseTypeDef]:
         """
-        [DescribeScalingPlans.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans.paginate)
+        [DescribeScalingPlans.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.32/reference/services/autoscaling-plans.html#AutoScalingPlans.Paginator.DescribeScalingPlans.paginate)
         """
